@@ -1,6 +1,5 @@
 from mixcoatl.resource import Resource
-from mixcoatl.admin import job
-from mixcoatl.utils import wait_for_job
+from mixcoatl.admin.job import Job
 from mixcoatl.utils import camel_keys
 from mixcoatl.decorators.validations import required_attrs
 from mixcoatl.decorators.lazy import lazy_property
@@ -13,7 +12,7 @@ class Server(Resource):
     collection_name = 'servers'
     primary_key = 'server_id'
 
-    def __init__(self, server_id = None, *args, **kwargs):
+    def __init__(self, server_id=None, *args, **kwargs):
         self.collection_name = self.__class__.collection_name
         Resource.__init__(self)
         self.__server_id = server_id
@@ -51,7 +50,7 @@ class Server(Resource):
 
     @data_center.setter
     def data_center(self, d):
-        self.__data_center = {u'data_center_id':d}
+        self.__data_center = {u'data_center_id': d}
 
     @lazy_property
     def description(self):
@@ -67,7 +66,7 @@ class Server(Resource):
 
     @machine_image.setter
     def machine_image(self, m):
-        self.__machine_image = {u'machine_image_id':m}
+        self.__machine_image = {u'machine_image_id': m}
 
     @lazy_property
     def firewalls(self):
@@ -151,8 +150,8 @@ class Server(Resource):
         elif self.current_job is None:
             self.load()
         else:
-            if wait_for_job(self.current_job):
-                self.server_id = job.get(self.current_job)['message']
+            if Job.wait_for(self.current_job):
+                self.__server_id = job.get(self.current_job)['message']
                 self.load()
             else:
                 return self.last_error
@@ -173,9 +172,10 @@ class Server(Resource):
 
         return self.put(p, data=json.dumps(payload))
 
-    @required_attrs(['provider_product_id', 'machine_image', 'description', 'name','data_center'])
+    @required_attrs(['provider_product_id', 'machine_image', 'description',
+                    'name', 'data_center'])
     def launch(self, callback=None):
-        optional_attrs = ['firewalls','keypair', 'label']
+        optional_attrs = ['firewalls', 'keypair', 'label']
         if self.server_id is not None:
             raise ServerLaunchException('Cannot launch an already running server: %s' % self.server_id)
 
